#'Wind power density on multidimensional array objects
#'
#'@author Llorenç Lledó, \email{llledo@bsc.es}
#'@description Wind Power Density computes the wind power that is available for extraction per square meter of swept area. 
#'@description It is computed as 0.5*ro*wspd^3. As this function is non-linear, it will give inaccurate results if used with period means.
#'
#'@param wind a multidimensional array, vector or scalar with instantaneous wind speeds expressed in m/s.
#'@param ro a scalar, or alternatively a multidimensional array with the same dimensions as wind, with the air density expressed in kg/m^3. By default it takes the value 1.225, the standard density of air at 15ºC and 1013.25 hPa.
#'@return An array with the same dimensions as wind, containing Wind Power Density expressed in W/m^2.
#'
#'@examples
#'wind <- rweibull(n = 100, shape = 2, scale = 6)
#'WPD <- WindPowerDensity(wind)
#'
#'@export
WindPowerDensity <- function(wind, ro = 1.225) {
	return(0.5 * ro * wind^3)
}
