% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/WindCapacityFactor.R
\name{WindCapacityFactor}
\alias{WindCapacityFactor}
\title{Wind capacity factor}
\usage{
WindCapacityFactor(wind, IEC_class = c("I", "I/II", "II", "II/III", "III"))
}
\arguments{
\item{wind}{a multidimensional array, vector or scalar with instantaneous wind speeds expressed in m/s.}

\item{IEC_class}{a string indicating the IEC wind class (see IEC 61400-1) of the turbine to be selected. Classes \code{'I'}, \code{'II'} and \code{'III'} are suitable for sites with an annual mean wind speed of 10, 8.5 and 7.5 m/s respectively. Classes \code{'I/II'} and \code{'II/III'} indicate intermediate turbines that fit both classes. More details of the five turbines and a plot of its power curves can be found in Lledó et al. (2019).}
}
\value{
An array with the same dimensions as wind, containing the Wind Capacity Factor (unitless).
}
\description{
Wind capacity factor computes the wind power generated by a specific wind turbine model under specific wind speed conditions, and expresses it as a fraction of the rated capacity (i.e. maximum power) of the turbine.

It is computed by means of a tabular power curve that relates wind speed to power output. The tabular values are interpolated with a linear piecewise approximating function to obtain a smooth power curve. Five different power curves that span different IEC classes can be selected (see below).
}
\examples{
wind <- rweibull(n = 100, shape = 2, scale = 6)
WCF <- WindCapacityFactor(wind, IEC_class = "III")

}
\references{
Lledó, Ll., Torralba, V., Soret, A., Ramon, J., & Doblas-Reyes, F. J. (2019). Seasonal forecasts of wind power generation. Renewable Energy, 143, 91–100. https://doi.org/10.1016/j.renene.2019.04.135

International Standard IEC 61400-1 (third ed.) (2005)
}
\author{
Llorenç Lledó, \email{llledo@bsc.es}
}
